<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.0">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>О програму...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Информације</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Преводиоци</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Лиценца</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>Јутуб%1 прегледач за СМПлејер</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Верзија: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Преносиво издање</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Компајлирано са  КуТ %1 (користећи %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Посетите наш веб сајт за ажурирања:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Многи су допринели са преводима.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>И ви можете помоћи да се СМТуб преведе на ваш језик.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Посетите %1 и прикључите се преводилачком тиму.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Кликните овде да видите преводиоце из Трансифекс тимова</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="138"/>
        <source>Home</source>
        <translation>Почетна</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="141"/>
        <source>Navigation</source>
        <translation>Навигација</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="149"/>
        <source>Zoom +</source>
        <translation>Зум +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="153"/>
        <source>Zoom -</source>
        <translation>Зум -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="157"/>
        <source>&amp;Quit</source>
        <translation>&amp;Изађи</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Навигација</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="172"/>
        <source>&amp;View</source>
        <translation>&amp;Приказ</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="173"/>
        <source>Toolbar</source>
        <translation>Трака алатки</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="177"/>
        <source>Statusbar</source>
        <translation>Трака стања</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="182"/>
        <source>&amp;Settings</source>
        <translation>По&amp;ставке</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="194"/>
        <source>&amp;Help</source>
        <translation>&amp;Помоћ</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="198"/>
        <source>&amp;Update YouTube playback support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="200"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="206"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;О СМТубу</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="331"/>
        <source>Download video using an external service</source>
        <translation>Преузми видео помоћу спољног сервиса</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="332"/>
        <source>Download</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="578"/>
        <source>No video found</source>
        <translation>Нема видеа</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Није било могуће наћи УРЛ за овај видео.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="610"/>
        <source>About...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="611"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="317"/>
        <source>Loading... %1%</source>
        <translation>Учитавам... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="232"/>
        <source>In order to play YouTube videos, %1 needs the help of an external application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="233"/>
        <source>%1 can download and install this application for you.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="234"/>
        <source>It will be downloaded from the official website and installed as %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="235"/>
        <source>Would you like to proceed?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="239"/>
        <location filename="../codedownloader.cpp" line="242"/>
        <source>Install YouTube support?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Поставке</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Опште</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="178"/>
        <source>&amp;Players</source>
        <translation>&amp;Плејери</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="226"/>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Up</source>
        <translation>Горе</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Репродукција</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Жељени &amp;квалитет:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="152"/>
        <source>YouTube support application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="237"/>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="261"/>
        <source>Edit</source>
        <translation>Уреди</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="274"/>
        <source>A&amp;dd predefined players</source>
        <translation>&amp;Додај предефинисане плејере</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="310"/>
        <source>&amp;Interface</source>
        <translation>&amp;Сучеље</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="318"/>
        <source>&amp;Style:</source>
        <translation>И&amp;зглед:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="354"/>
        <source>Font:</source>
        <translation>Фонт:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="368"/>
        <source>C&amp;hange...</source>
        <translation>Из&amp;мени...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Преузми видео помоћу &amp;спољног сервиса</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="202"/>
        <source>Down</source>
        <translation>Доле</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="82"/>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="460"/>
        <source>yt-dlp (based on youtube-dl with improvements)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="478"/>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Кликните за избор фајла или фасцикле</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>Отвори на Јутубу</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Сачувај везу...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>Копирај &amp;везу у клипборд</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Отвори везу у овом прозору</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>&amp;Копирај текст у клипборд</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Отвори везу у &amp;новом прозору</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Пусти помоћу</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>Пусти &amp;аудио помоћу</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>&amp;Пусти помоћу %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="145"/>
        <source>Play &amp;audio with %1</source>
        <translation>Пусти &amp;аудио помоћу %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="154"/>
        <source>Play video with a &amp;web browser</source>
        <translation>Пусти &amp;видео у прегледачу</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Уреди плејер</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Назив:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Извршни фајл:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Параметри:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Овај плејер подржава &amp;видео сајтове</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Овај плејер може да пушта &amp;интернет ТВ</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Жељени &amp;квалитет:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Додај у &amp;мени:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Видео и аудио</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../version.cpp" line="48"/>
        <source>%1 (revision %2) %3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../version.cpp" line="50"/>
        <source>%1 (revision %2)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>